@@ -11,7 +11,7 @@ import bokeh.io as bkio
 from bokeh.layouts import gridplot
 from bokeh.plotting import Figure
 
-__version__ = "0.4.1"
+__version__ = "0.5.0"
 
 # we don't run a comprehensive test suite and mostly in notebooks,
 # so show warnings all the time.
@@ -162,7 +162,7 @@ def cli():
     subparsers.required = True
 
     # add reporting modules
-    modules = ['bcfstats', 'mapula', 'nextclade', 'fastcat', 'clonevalidation']
+    modules = ['demo', 'bcfstats', 'mapula', 'nextclade', 'fastcat', 'simple']
     for module in modules:
         mod = importlib.import_module('aplanat.components.{}'.format(module))
         p = subparsers.add_parser(module, parents=[mod.argparser()])
